netapp_ontap.models.node_ha API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.node_ha`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class NodeHaSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the NodeHa object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `auto_giveback GET`

    Specifies whether giveback is automatically initiated when the node that owns the storage is ready.

  `enabled GET`

    Specifies whether or not storage failover is enabled.

  `giveback GET POST PATCH`

    The giveback field of the node_ha.

  `partners GET`

    Nodes in this node's High Availability (HA) group.

  `ports GET`

    The ports field of the node_ha.

  `takeover GET POST PATCH`

    The takeover field of the node_ha.